[jboss-cvs] JBossAS SVN: r83083 - in projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi: endpoint and 1 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Mon Jan 19 15:07:31 EST 2009


Author: jesper.pedersen
Date: 2009-01-19 15:07:31 -0500 (Mon, 19 Jan 2009)
New Revision: 83083

Added:
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableException.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableUnavailableException.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/RetryableWorkRejectedException.java
Modified:
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ActivationSpec.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/BootstrapContext.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ConfigProperty.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/Connector.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/DissociatableManagedConnection.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ManagedConnection.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/endpoint/MessageEndpointFactory.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/DistributableWork.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/ExecutionContext.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/HintsWorkContext.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/SecurityWorkContext.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/TransactionWorkContext.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/WorkManager.java
   projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/package.html
Log:
[JBJCA-37] Merge API changes from Public Final Draft

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ActivationSpec.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ActivationSpec.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ActivationSpec.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -41,15 +41,14 @@
     * validation. The implementation of this self-validation check behavior is
     * optional.
     * 
-    * @throws <code>InvalidPropertyException</code> indicates invalid
-    *         configuration property settings.
-    *         
-    * @deprecated As of Java EE Connectors 1.6 specification, resource adapter
-    *             implementations are recommended to use the annotations or the
-    *             XML validation deployment descriptor facilities defined by
-    *             the Bean Validation specification to express their validation
-    *             requirements of its configuration properties to the
-    *             application server.
-    */
+    * Note: As of Java EE Connectors 1.6 specification, resource adapter
+    *       implementations are recommended to use the annotations or the
+    *       XML validation deployment descriptor facilities defined by
+    *       the Bean Validation specification to express their validation
+    *       requirements of its configuration properties to the
+    *       application server.
+    *
+    * @throws InvalidPropertyException indicates invalid configuration property settings.
+    */         
    void validate() throws InvalidPropertyException;
 }

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/BootstrapContext.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ConfigProperty.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ConfigProperty.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -60,4 +60,18 @@
     * Property during auto-discovery of Configuration properties.
     */
    boolean ignore() default false;
+
+   /**
+    * Indicates that the configuration property supports
+    * dynamic updates to its value during the lifetime of
+    * the JavaBean
+    */
+   boolean supportsDynamicUpdates() default false;
+   
+   /**
+    * Indicates that the configuration property is confidential and
+    * recommends application server's configuration tools to 
+    * use special visual aids for editing them. 
+    */
+   boolean confidential() default false;
 }

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/Connector.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/Connector.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/Connector.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -44,10 +44,18 @@
 public @interface Connector 
 {
    
+   /**
+    * Describes the resource adapter module.
+    */
    String[] description() default {};
    
+   /**
+    * An optional short name, providing information about the
+    * resource adapter module,  that is intended to be displayed 
+    * by tools.
+    */
    String[] displayName() default {};
-   
+ 
    /**
     * Specifies the file name for small GIF or JPEG icon images that are 
     * used to represent the resource adapter in a GUI tool. 
@@ -138,8 +146,8 @@
    
    /**
     * Specifies a list of fully qualified classes that implements the
-    * {@link WorkContext InflowContext} interface that a resource adapter
+    * {@link WorkContext WorkContext} interface that a resource adapter
     * requires the application server to support.
     */
-   Class<? extends WorkContext>[] requiredInflowContexts() default {};
+   Class<? extends WorkContext>[] requiredWorkContexts() default {};
 }

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/DissociatableManagedConnection.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/DissociatableManagedConnection.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/DissociatableManagedConnection.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -45,9 +45,10 @@
     *
     * @throws ResourceAdapterInternalException
     *            resource adapter internal error condition
-    * @throws IllegalStateException Illegal state for calling connection
-    *            cleanup. Example - if a localtransaction is in progress 
-    *            that doesn't allow connection cleanup.
+    * @throws IllegalStateException
+    *         Illegal state for dissociating a
+    *         <code>ManagedConnection</code> from all of its connection
+    *         handles.
     */
    void dissociateConnections() throws ResourceException;
 }

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ManagedConnection.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ManagedConnection.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ManagedConnection.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -136,6 +136,10 @@
     *  application-level connection handle with a ManagedConneciton 
     *  instance. The container should find the right ManagedConnection 
     *  instance and call the associateConnection method.
+    *  In order to set a Connection Handle as the active connection 
+    *  handle, the container may also use the <code>associateConnection</code> 
+    *  method to set the same <code>ManagedConnection</code> associated 
+    *  with the Connection handle.
     *
     *  <p>The resource adapter is required to implement the associateConnection
     *  method. The method implementation for a ManagedConnection should 

Added: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableException.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableException.java	                        (rev 0)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableException.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -0,0 +1,38 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2008, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package javax.resource.spi;
+
+import java.io.Serializable;
+
+/**
+ * A marker interface indicating that the Exception is transient. It is used
+ * in situations where a previously failed operation might be able to succeed 
+ * if the resource adapter performs some recovery steps and retries the
+ * operation.
+ * 
+ * @since 1.6
+ * @version JSR322-PublicReview
+ */
+public interface RetryableException extends Serializable 
+{
+}

Added: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableUnavailableException.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableUnavailableException.java	                        (rev 0)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/RetryableUnavailableException.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -0,0 +1,89 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2008, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package javax.resource.spi;
+
+/**
+ * A subclass of the <code>UnavailableException</code> that 
+ * indicates that the rejection of the work submission is transient. 
+ * It is thrown in situations where the previously failed work submission 
+ * might be able to succeed if the resource adapter retries the operation
+ * at a later point in time.
+ * 
+ * @since 1.6
+ * @version JSR322-PublicReview
+ */
+public class RetryableUnavailableException extends UnavailableException implements RetryableException 
+{
+   /**
+    * Determines if a deserialized instance of this class
+    * is compatible with this class.
+    */
+   private static final long serialVersionUID = 3730185319227786830L;
+   
+   /**
+    * Constructs a new instance with null as its detail message.
+    */
+   public RetryableUnavailableException() 
+   {
+      super();
+   }
+   
+   /**
+    * Constructs a new instance with the specified detail message.
+    * @param message the detail message.
+    */
+   public RetryableUnavailableException(String message) 
+   {
+      super(message);
+   }
+   
+   /**
+    * Constructs a new throwable with the specified cause.
+    * @param cause a chained exception of type <code>Throwable</code>.
+    */
+   public RetryableUnavailableException(Throwable cause) 
+   {
+      super(cause);
+   }
+
+   /**
+    * Constructs a new throwable with the specified detail message and cause.
+    * @param message the detail message.
+    * @param cause a chained exception of type <code>Throwable</code>.
+    */
+   public RetryableUnavailableException(String message, Throwable cause) 
+   {
+      super(message, cause);
+   }
+
+   /**
+    * Constructs a new throwable with the specified detail message and
+    * an error code.
+    * @param message a description of the exception.
+    * @param errorCode a string specifying the vendor specific error code.
+    */
+   public RetryableUnavailableException(String message, String errorCode) 
+   {
+      super(message, errorCode);
+   }
+}

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/endpoint/MessageEndpointFactory.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/endpoint/MessageEndpointFactory.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/endpoint/MessageEndpointFactory.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -52,6 +52,30 @@
       throws UnavailableException;
    
    /**
+    * This is used to create a message endpoint. The message endpoint is
+    * expected to implement the correct message listener type.
+    *
+    * @param xaResource an optional <code>XAResource</code> 
+    * instance used to get transaction notifications when the message delivery
+    * is transacted.
+    * 
+    * @param timout an optional value used to specify the time duration
+    * (in milliseconds) within which the message endpoint needs to be
+    * created by the <code>MessageEndpointFactory</code>. Otherwise, the
+    * <code>MessageEndpointFactory</code> rejects the creation of the
+    * <code>MessageEndpoint</code> with an UnavailableException.  Note, this
+    * does not offer real-time guarantees.
+    * 
+    * @return a message endpoint instance.
+    *
+    * @throws UnavailableException indicates a transient failure
+    * in creating a message endpoint. Subsequent attempts to create a message
+    * endpoint might succeed.
+    */
+   MessageEndpoint createEndpoint(XAResource xaResource, long timeout)
+      throws UnavailableException;
+
+   /**
     * This is used to find out whether message deliveries to a target method
     * on a message listener interface that is implemented by a message 
     * endpoint will be transacted or not. 

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/DistributableWork.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/DistributableWork.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/DistributableWork.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -22,10 +22,6 @@
 
 package javax.resource.spi.work;
 
-import java.lang.Object;
-import java.lang.Runnable;
-import java.lang.Exception;
-import java.lang.Throwable;
 import java.io.Serializable;
 
 /**

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/ExecutionContext.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/ExecutionContext.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/ExecutionContext.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -22,13 +22,8 @@
 
 package javax.resource.spi.work;
 
-import java.lang.Object;
-import java.lang.Runnable;
-import java.lang.Exception;
-import java.lang.Throwable;
-
-import javax.transaction.xa.Xid;
 import javax.resource.NotSupportedException;
+import javax.transaction.xa.Xid;
 
 /**
  * This class models an execution context (transaction, security, etc) 
@@ -50,8 +45,8 @@
  *
  * Note: Resource adapters that are developed for Connectors 1.6 specification
  * compliant application servers and above, are recommended to use
- * the <code>TransactionInflowContext</code> interface instead of this 
- * class. See Chapter.11 Generic Inflow Context in the Connectors 1.6
+ * the <code>TransactionWorkContext</code> interface instead of this 
+ * class. See Chapter.11 Generic Work Context in the Connectors 1.6
  * specification for more details.
  *
  * @version 1.0

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/HintsWorkContext.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/HintsWorkContext.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/HintsWorkContext.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -38,9 +38,19 @@
 
 public class HintsWorkContext implements WorkContext 
 {
-   String description = "Hints Inflow Context";
-   String name = "HintsWorkContext";
+
+   /**
+    * Determines if a deserialized instance of this class
+    * is compatible with this class.
+    */
+   private static final long serialVersionUID = 7956353628297167255L;
    
+   public static final String NAME_HINT = "javax.resource.Name";
+   public static final String LONGRUNNING_HINT = "javax.resource.LongRunning";
+   
+   protected String description = "Hints Work Context";
+   protected String name = "HintsWorkContext";
+   
    /**
     * {@inheritDoc}
     */

Added: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/RetryableWorkRejectedException.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/RetryableWorkRejectedException.java	                        (rev 0)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/RetryableWorkRejectedException.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -0,0 +1,91 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2008, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package javax.resource.spi.work;
+
+import javax.resource.spi.RetryableException;
+
+/**
+ * A subclass of the <code>WorkRejectedException</code> that 
+ * indicates that the the service unavailability is transient. It is thrown in
+ * situations where the previously failed operation might be able to succeed if the 
+ * resource adapter performs some recovery steps and retries the operation.
+ * 
+ * @since 1.6
+ * @version JSR322-PublicReview
+ */
+public class RetryableWorkRejectedException extends WorkRejectedException implements RetryableException 
+{
+   
+   /**
+    * Determines if a deserialized instance of this class
+    * is compatible with this class.
+    */
+   private static final long serialVersionUID = 8198870267352154108L;
+   
+   /**
+    * Constructs a new instance with null as its detail message.
+    */
+   public RetryableWorkRejectedException() 
+   {
+      super();
+   }
+   
+   /**
+    * Constructs a new instance with the specified detail message.
+    * @param message the detail message.
+    */
+   public RetryableWorkRejectedException(String message) 
+   {
+      super(message);
+   }
+   
+   /**
+    * Constructs a new throwable with the specified cause.
+    * @param cause a chained exception of type <code>Throwable</code>.
+    */
+   public RetryableWorkRejectedException(Throwable cause) 
+   {
+      super(cause);
+   }
+   
+   /**
+    * Constructs a new throwable with the specified detail message and cause.
+    * @param message the detail message.
+    * @param cause a chained exception of type <code>Throwable</code>.
+    */
+   public RetryableWorkRejectedException(String message, Throwable cause)
+   {
+      super(message, cause);
+   }
+   
+   /**
+    * Constructs a new throwable with the specified detail message and
+    * an error code.
+    * @param message a description of the exception.
+    * @param errorCode a string specifying the vendor specific error code.
+    */
+   public RetryableWorkRejectedException(String message, String errorCode) 
+   {
+      super(message, errorCode);
+   }
+}

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/SecurityWorkContext.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/SecurityWorkContext.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/SecurityWorkContext.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -78,12 +78,17 @@
 
 public abstract class SecurityWorkContext implements WorkContext 
 {
+   /**
+    * Determines if a deserialized instance of this class
+    * is compatible with this class.
+    */
+   private static final long serialVersionUID = 7730296651802712658L;
    
    /**
     * {@inheritDoc}
     */
    public String getDescription() {
-      return "Security Inflow Context";
+      return "Security Work Context";
    }
    
    /**

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/TransactionWorkContext.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/TransactionWorkContext.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/TransactionWorkContext.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -41,10 +41,16 @@
 public class TransactionWorkContext extends ExecutionContext implements WorkContext 
 {
    /**
+    * Determines if a deserialized instance of this class
+    * is compatible with this class.
+    */
+   private static final long serialVersionUID = 6205067498708597824L;
+
+   /**
     * {@inheritDoc}
     */
    public String getDescription() {
-      return "Transaction Inflow Context";
+      return "Transaction Work Context";
    }
 
    /**

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/WorkManager.java
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/WorkManager.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/WorkManager.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -84,7 +84,8 @@
    
    /**
     * A constant to indicate timeout duration. A zero timeout value indicates
-    * an action be performed immediately.
+    * an action be performed immediately. The WorkManager implementation
+    * must timeout the action as soon as possible.
     */
    long IMMEDIATE = 0L;
    
@@ -106,7 +107,7 @@
     * blocks until the <code>Work</code> instance completes execution.
     * There is no guarantee on when the accepted <code>Work</code> 
     * instance would start execution ie., there is no time constraint 
-    * to start execution.
+    * to start execution. (that is, startTimeout=INDEFINITE)
     *
     * @param work The unit of work to be done.  
     * Could be long or short-lived.
@@ -118,7 +119,7 @@
     * @throws WorkCompletedException indicates that a
     * <code>Work</code> instance has completed execution with an exception.
     */
-   void doWork(Work work) // startTimeout = INDEFINITE
+   void doWork(Work work)
       throws WorkException;
    
    /**
@@ -161,7 +162,8 @@
     * blocks until the <code>Work</code> instance starts execution
     * but not until its completion. There is no guarantee on when
     * the accepted <code>Work</code> instance would start
-    * execution ie., there is no time constraint to start execution.
+    * execution ie., there is no time constraint to start execution
+    * (that is, startTimeout=INDEFINITE)
     *
     * @param work The unit of work to be done.  
     * Could be long or short-lived.
@@ -175,7 +177,7 @@
     * <code>Work</code> instance has been rejected from further processing.
     * This can occur due to internal factors.
     */
-   long startWork(Work work) // startTimeout = INDEFINITE
+   long startWork(Work work)
       throws WorkException;
    
    /**
@@ -223,7 +225,8 @@
     * does not block and returns immediately once a <code>Work</code>
     * instance has been accepted for processing. There is no guarantee
     * on when the submitted <code>Work</code> instance would start
-    * execution ie., there is no time constraint to start execution.
+    * execution ie., there is no time constraint to start execution
+    * (that is, startTimeout=INDEFINITE).
     *
     * @param work The unit of work to be done.  
     * Could be long or short-lived.
@@ -232,7 +235,7 @@
     * <code>Work</code> instance has been rejected from further processing.
     * This can occur due to internal factors.
     */
-   void scheduleWork(Work work) // startTimeout = INDEFINITE
+   void scheduleWork(Work work)
       throws WorkException;
    
    /**

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/package.html
===================================================================
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/package.html	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/work/package.html	2009-01-19 20:07:31 UTC (rev 83083)
@@ -2,6 +2,6 @@
 <head>
 </head>
 <body>
-This package contains APIs for the Work Management, Generic Inflow and Security Inflow contracts.
+This package contains APIs for the Work Management, Generic Work and Security Work contracts.
 </body>
 </html>




More information about the jboss-cvs-commits mailing list
--- projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/BootstrapContext.java	2009-01-19 20:06:05 UTC (rev 83082)
+++ projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/BootstrapContext.java	2009-01-19 20:07:31 UTC (rev 83083)
@@ -73,28 +73,28 @@
    
    /**
     * A resource adapter can check an application server’s support 
-    * for a particular InflowContext type through this method. 
+    * for a particular WorkContext type through this method. 
     * This mechanism enables a resource adapter developer to
-    * dynamically change the InflowContexts submitted with a Work instance 
+    * dynamically change the WorkContexts submitted with a Work instance 
     * based on the support provided by the application server.
     *
     * The application server must employ an exact type equality check (that is
     * <code>java.lang.Class.equals(java.lang.Class)</code> check) in
-    * this method, to check if it supports the InflowContext type provided
+    * this method, to check if it supports the WorkContext type provided
     * by the resource adapter. This method must be idempotent, that is all 
     * calls to this method by a resource adapter for a particular 
-    * <code>InflowContext</code> type must return the same boolean value 
+    * <code>WorkContext</code> type must return the same boolean value 
     * throughout the lifecycle of that resource adapter instance.
     *
     * @return true if the <code>inflowContextClass</code> is supported
     * by the application server. false if the <code>inflowContextClass</code>
     * is unsupported or unknown to the application server.
     *
     * @since 1.6
     */
+   boolean isContextSupported(Class<? extends WorkContext> workContextClass);
    
-   boolean isContextSupported(Class<? extends WorkContext> inflowContextClass);
-   
    /**
     * Provides a handle to a <code>TransactionSynchronization</code> instance. The
     * <code>TransactionSynchronizationRegistry</code> instance could be used by a 
@@ -73,28 +73,28 @@
     * throughout the lifecycle of that resource adapter instance.
     *
-    * @return true if the <code>inflowContextClass</code> is supported
-    * by the application server. false if the <code>inflowContextClass</code>
+    * @param workContextClass The work context class
+    * @return true if the <code>workContextClass</code> is supported
+    * by the application server. false if the <code>workContextClass</code>
     * is unsupported or unknown to the application server.
     *

Modified: projects/jboss-jca/trunk/api/src/main/java/javax/resource/spi/ConfigProperty.java
===================================================================